<?php

// periods types
function pcpp_periods($sel = false) {
	$per = array(
		'day' 	=> __('days', 'pcpp_ml'),
		'week' 	=> __('weeks', 'pcpp_ml'),
		'month' => __('months', 'pcpp_ml'),
		'year' 	=> __('years', 'pcpp_ml'),
	);
	
	if(!$sel) {
		return $per;	
	} else {
		return $per[$sel];		
	}	
}


// periods - return related seconds
function pcpp_periods_to_sec($dur) {
	$secs = array(
		'day' 	=> 86400,
		'week' 	=> 604800,
		'month' => 2592000,
		'year' 	=> 3153600,
	);	
	
	return $secs[$dur];
}


// switch for singular/plural time formats
function pcpp_sing_plur_switch($subj, $val) {
	switch($subj) {
		case 'day':
			$period = ($val > 1) ? pcpp_periods($subj) : __('day', 'pcpp_ml'); 
			break;
			
		case 'week':
			$period = ($val > 1) ? pcpp_periods($subj) : __('week', 'pcpp_ml'); 
			break;
			
		case 'month':
			$period = ($val > 1) ? pcpp_periods($subj) : __('month', 'pcpp_ml'); 
			break;		
		
		case 'year':
			$period = ($val > 1) ? pcpp_periods($subj) : __('year', 'pcpp_ml'); 
			break;			
	}
	return $period;
}


// subscription statuses list
function pcpp_subscr_statuses($status = false) {
	$statuses = array(
		'trial'		=> __('Trial period', 'pcpp_ml'),
		'unpaid'	=> __('Unpaid', 'pcpp_ml'),
		'no_act_order'	=> __('No Active Orders', 'pcpp_ml'),
		'expired'	=> __('Expired', 'pcpp_ml'),
		'active'	=> __('Active', 'pcpp_ml'),
	);
	
	return ($status) ? $statuses[$status] : $statuses;	
}


// given order ID - return its ecommerce status for admin orders list
function pcpp_get_order_ecomm_status($order_id) {
	if(PCPP_ECOMMERCE == 'woocomm') {
		$statuses = wc_get_order_statuses();
		$raw_status = get_post_status($order_id);

		// if completed - print date
		if($raw_status == 'wc-completed') {
			return $statuses[$raw_status] .' '. pcpp_order_id_to_paydate_html($order_id);	
		} else {
			return (isset($statuses[$raw_status])) ? $statuses[$raw_status] : '';	
		}
	}
	
	return '';	
}


// given order ID - return its final amount
function pcpp_get_order_amount($order_id) {
	if(PCPP_ECOMMERCE == 'woocomm') {
		$order = wc_get_order($order_id);
      	$total = (float)$order->get_total();
		
		return (empty($total)) ? __('free', 'pcpp_ml') : get_woocommerce_currency_symbol() . $total;
	}
	
	return '';	
}


// plan details - to be used in admin dropdowns
function pcpp_dd_plan_details($plan_id) {
	global $pcpp_subscr;	
	$p_data = $pcpp_subscr->get_plan_data($plan_id);
	
	$duration = empty($p_data['duration']) ? __('one-time fee', 'pcpp_ml') : __('for', 'pcpp_ml') .' '.$p_data['duration'].' '.pcpp_sing_plur_switch($p_data['duration_type'], $p_data['duration']);
	
	return ' - '.$p_data['currency_price'].' '. $duration;
}



// WPML - get original language object ID
function pcpp_wpml_get_orig_id($subj_id, $post_type = 'product') {
	if(function_exists('icl_object_id')) {
		global $sitepress;
		$subj_id = icl_object_id($subj_id, $post_type, false, $sitepress->get_default_language());	
	}	
	return $subj_id;
}


// WPML & Polylang - get translation object ID for plans
function pcpp_wpml_get_trans_id($subj_id) {
	
	// WPML
	if(function_exists('icl_object_id')) {
		switch(PCPP_ECOMMERCE) {
			case 'woocomm'	: $post_type = 'product'; break;
			default			: $post_type = ''; break;	
		}
		
		$subj_id = icl_object_id($subj_id, $post_type, false);	
	}	
	
	// Polylang
	if(function_exists('pll_get_post')) {
		$subj_id = pll_get_post($subj_id);	
	} 	
	
	return $subj_id;
}



// given duration and duration subject - returns ending date in seconds or mysql
function pcpp_get_ending_date($period, $period_subj, $to_get = 'time', $starting_date = false) {
	
	// no period - return current data
	if(!$period){
		return ($to_get == 'time') ? current_time('timestamp') : current_time('mysql');	
	}
	
	// sanitize subject	
	if(!in_array($period_subj, array('day', 'week', 'month', 'year'))) {
		$period_subj = 'day';	
	}
	
	if(!$starting_date) {$starting_date = current_time('mysql');}
	$date = new DateTime( $starting_date );
	$date->modify('+'. (int)$period .' '.$period_subj);
	
	return ($to_get == 'time') ? $date->format('U') : $date->format('Y-m-d H:i:s');	
}


// given time value (seconds) - returns the date
function pcpp_time_to_date_html($time) {
	if($time == 'unlimited') {return __('Unlimited Plan', 'pcpp_ml');}
	
	$date_format = get_option('date_format');
	
	return '<time title="'. date_i18n($date_format .' - '. get_option('time_format'), $time) .' '. get_option('timezone_string') .' timezone">'. date_i18n($date_format, $time) .'</time>';	
}


// given order ID - return HTML code with icon showing payment date
function pcpp_order_id_to_paydate_html($order_id) {
	$paydate = get_post_meta($order_id, 'pcpp_payment_date', true);
	if(empty($paydate)) {return '';}
	
	$date_format = get_option('date_format');
	
	return '<img src="'.PCPP_URL.'/img/clock.png" title="'. __('Paid on', 'pcpp_ml') .': '. date_i18n(get_option('date_format') .' - '. get_option('time_format'), strtotime($paydate) ) .'
	 '. get_option('timezone_string') .' timezone" class="pcpp_order_paydate" />';	
}


// e-commerce systems that can be used by the add-on
function pcpp_avail_ecomm($get_first = false) {
	$avail = array();
	
	if(is_plugin_active('woocommerce/woocommerce.php')) {
		$avail['woocomm'] = 'WooCommerce';
		
		// set woocomm version into a constant
		if(!defined('PCPP_WC_VER')) {
			$plugin_folder = get_plugins( '/' . 'woocommerce' );
			$plugin_file = 'woocommerce.php';
			
			$ver = (isset( $plugin_folder[$plugin_file]['Version'])) ? $plugin_folder[$plugin_file]['Version'] : '2.9'; // fake - but still v2
			define('PCPP_WC_VER', $ver);
		}
	}
	
	
	if(!empty($avail) && $get_first) {
		$keys = array_keys($avail);
		return $keys[0];
	} else {
		return $avail;
	}
}


// compose plan text to be shown in form
function pcpp_plan_form_txt($plan_data, $plan_name) {
	$is_free 	= ((float)$plan_data['price']) ? false : true;
	$has_period = (empty($plan_data['duration_secs'])) ? false : true;
	
	$parts = array(
		'<span class="pcpp_plan_name">'.$plan_name,'</span>',
		'<span class="pcpp_plan_price_wrap">'
	);

	// price
	$price_txt 		= ($is_free) ? __('free', 'pcpp_ml') : $plan_data['currency_price'];
	$is_free_class	= ($is_free) ? 'pcpp_is_free' : '';
 	
	$parts[] = '<strong class="pcpp_plan_price '. $is_free_class .'">'. $price_txt .'</strong>';
	
	// subscription duration
	$parts[] = ($has_period) ? 
		'<span class="pcpp_plan_dur">'. __('for', 'pcpp_ml') .' <strong>'.$plan_data['duration_txt'].'</strong></span>' : 
		'<strong class="pcpp_plan_dur">'. __('one-time fee', 'pcpp_ml') .'</strong>';
	
	// end price block
	$parts[] = '</span>';
	
	// plan description
	if(strip_tags($plan_data['txt'])) {
		$parts[] = '<div class="pcpp_plan_descr">'. do_shortcode($plan_data['txt']) .'</div>';	
	}
	
	return implode(' ', $parts);	
}



// edit expiration date code
function pcpp_edit_exp_date_code($exp_date) {
	if(empty($exp_date) || $exp_date == 'unlimited') {
		$date = '';
		$hour = '';
		$min = '';	
	} else {
		if(filter_var($exp_date, FILTER_VALIDATE_INT)) {$exp_date = date('Y-m-d H:i:s', $exp_date);}
		
		$obj = new DateTime($exp_date);
		$date = $obj->format('Y/m/d');
		$hour = $obj->format('H');
		$min = $obj->format('i');
	}
	
	$code = '
	<input type="text" id="pcpp_edit_exp_date" value="'.$date.'" autocomplete="off" style="width: 95px; text-align: center;" /> '. __('at', 'pcpp_ml') .' 
	<select name="pcpp_edit_exp_hour" id="pcpp_edit_exp_hour" autocomplete="off">';
	
		for($a=0; $a<=23; $a++) {
			$val = ($a < 10) ? '0'.$a : $a;
			$sel = ($val == $hour) ? 'selected="selected"' : '';
			$code .= '<option value="'. $val .'" '.$sel.'>'.$val.'</option>';		
		}
		
	$code .= '
	</select> : 
	<select name="pcpp_edit_exp_min" id="pcpp_edit_exp_min" autocomplete="off" style="margin-right: 15px;">';
		
		for($a=0; $a<=60; $a++) {
			$val = ($a < 10) ? '0'.$a : $a;
			$sel = ($val == $min) ? 'selected="selected"' : '';
			$code .= '<option value="'. $val .'" '.$sel.'>'.$val.'</option>';		
		}
		
	$code .= '
	</select>';
	
	return $code;
}
