<?php
/* 
Plugin Name: PrivateContent - Premium Plans Add-on 
Plugin URI: http://www.lcweb.it/privatecontent/premium-plans-add-on
Description: Extend PrivateContent implementing pay and time limited subscriptions, also extend restriction engine basing on plans. Everthing simply taking advantage of WooCommerce
Author: پرشین اسکریپت
Version: 1.26
Author URI: http://www.persianscript.ir
*/  


/////////////////////////////////////////////
/////// MAIN DEFINES ////////////////////////
/////////////////////////////////////////////

// plugin path
$wp_plugin_dir = substr(plugin_dir_path(__FILE__), 0, -1);
define('PCPP_DIR', $wp_plugin_dir );

// plugin url
$wp_plugin_url = substr(plugin_dir_url(__FILE__), 0, -1);
define('PCPP_URL', $wp_plugin_url );

// plugin version
define('PCPP_VER', 1.26);


//////////////////////////////////////////////////////////
// CHECK IF PRIVATECONTENT AND E-COMM SYSTEM ARE ACTIVE //
//////////////////////////////////////////////////////////

include_once(ABSPATH . 'wp-admin/includes/plugin.php');
include_once(PCPP_DIR .'/functions.php');

if(!is_plugin_active('private-content/private_content.php') && !defined('PC_VERS')) {
	function pcpp_no_plugin_warning() {
		echo '
		<div class="error">
		   <p>'. __('Please activate PrivateContent plugin to use the "Premium Plans" add-on', 'pcpp_ml') .'</p>
		</div>';
	}
	add_action('admin_notices', 'pcpp_no_plugin_warning');
}

// check available e-comm systems and require at least one - actually only woocomm
else if(pcpp_avail_ecomm() === array()) {
	function pcpp_no_plugin_warning() {
		global $current_screen;

		// message only in pvtContent settings if is bundle
		if(isset($GLOBALS['is_pc_bundle']) && $current_screen->base == 'privatecontent_page_pc_settings') {
		
			echo '
			<div class="error">
			   <p>'. __('Please activate <a href="https://wordpress.org/plugins/woocommerce/" target="_blank">WooCommerce</a> plugin to use PrivateContent "Premium Plans" add-on', 'pcpp_ml') .'</p>
			</div>';
		}
	}
	add_action('admin_notices', 'pcpp_no_plugin_warning');
}



else {
	/////////////////////////////////////////////
	/////// MULTILANGUAGE SUPPORT ///////////////
	/////////////////////////////////////////////
	
	function pcpp_multilanguage() {
		$param_array = explode(DIRECTORY_SEPARATOR, PCPP_DIR);
		$folder_name = end($param_array);
	  	
		load_plugin_textdomain('pcpp_ml', false, $folder_name . '/languages'); 
	}
	add_action('init', 'pcpp_multilanguage', 1);
	
	
	
	//////////////////////////////////
	// SCRIPT ENQUEUING
	function pcpp_global_scripts() { 
		global $current_screen;
		
		if (is_admin()) {
			wp_enqueue_style('pcpp_admin', PCPP_URL .'/css/admin.css', 999, PCPP_VER);	
						
			if(strpos($_SERVER["REQUEST_URI"], '?page=pc_add_user') !== false) {
				wp_enqueue_script("jquery-ui-datepicker"); 
				wp_enqueue_style('pcpp_datepicker', PCPP_URL .'/css/datepicker/pcpp_light.theme.min.css', 999, PCPP_VER);	
				
				// datepicker localization
				global $wp_locale;	
	
				$str_array = array(
					'monthNames'        => array_values( $wp_locale->month ),
					'monthNamesShort'   => array_values( $wp_locale->month_abbrev ),
					'dayNames'          => array_values( $wp_locale->weekday ),
					'dayNamesShort'     => array_values( $wp_locale->weekday_abbrev ),
					'dayNamesMin'       => array_values( $wp_locale->weekday_initial),
					'firstDay'          => get_option('start_of_week'),
					'isRTL'             => (isset($wp_locale->text_direction) && $wp_locale->text_direction == 'rtl') ? true : false,
				);
				wp_localize_script('jquery-ui-datepicker', 'pcpp_datepick_str', $str_array);	
			}
		}	
		else {
			wp_enqueue_script('pcpp_frontend', PCPP_URL .'/js/frontend.js', 999, PCPP_VER, true);
			
			// frontend style switch
			$style = get_option('pg_style', 'minimal');
			if($style != 'custom') {
				wp_enqueue_style('pcpp_frontend_'.$style, PCPP_URL .'/css/'. $style .'.css', 999, PCPP_VER);		
			} else {
				wp_enqueue_style('pcpp_frontend', PCPP_URL .'/css/frontend.css', 900, PCPP_VER);			
			}
		}
	}
	add_action('init', 'pcpp_global_scripts');
	
	
	// javascript variables for multilang compatibility
	function pcpp_multilang_js_vars() {
		?>
        <script type="text/javascript">
		pcpp_renew_is_acting = "<em><?php _e('Creating order', 'pcpp_ml') ?>..</em>";
		pcpp_renew_ok = "<em><?php _e('Order successfully created', 'pcpp_ml') ?>!</em>";
		pcpp_failed_renew = "<em><?php _e('Problem creating order, try again', 'pcpp_ml') ?></em>";
		</script>
        <?php 
	}
	add_action('wp_head', 'pcpp_multilang_js_vars', 999);	


	
	////////////////////////////////////////////////
	// ADD-ON-IS-INTEGRATED CONSTANT - also checks if can be maintained counting plans
	$GLOBALS['pcpp_enabled'] = get_option('pcpp_enabled', false); // global to be overrided and to be ready in any hook
	
	/*function pcpp_is_integrated_flag() {
		
		if(is_admin() && $GLOBALS['pcpp_enabled']) { // use is_admin() to avoid interferences
			global $pcpp_subscr;
			$plans = $pcpp_subscr->get_plans(false);
			
			if(empty($plans)) {
				$GLOBALS['pcpp_enabled'] = false;
				update_option('pcpp_enabled', false);
				
				// show notice - use cookie otherwise won't be executed in most cases
				if(current_user_can('install_plugins')) {
					setcookie('pcpp_forced_disabling', 1, (time() + (60 * 60)), '/');
				}
			}
		}
	}
	add_action('admin_footer', 'pcpp_is_integrated_flag');*/
	
	
	
	function pcpp_forced_disabling_mess() {
		if(isset($_COOKIE['pcpp_forced_disabling'])) {
			echo '
			<div class="error">
			   <p>PivateContent Premium Plans add-on - '. __('disabled integration because of no available plans', 'pcpp_ml') .'</p>
			</div>';
			
			setcookie('pcpp_forced_disabling', 1, (time() - (60 * 60)), '/');
		}
	}
	add_action('admin_notices', 'pcpp_forced_disabling_mess');	
	
	
	
	////////////////////////////////////////////////
	// SET E-COMM TO USE IN A CONSTANT
	function pcpp_ecomm_to_use() {
		include_once(PCPP_DIR .'/functions.php');
		
		$to_use = false;
		$ecomm_to_use = get_option('pcpp_ecomm_to_use', false);
		$available = pcpp_avail_ecomm();
		
		if(count($available) == 1) {
			$keys = array_keys($available);
			define('PCPP_ECOMMERCE', $keys[0]);	
		}
		else {	
			foreach($available as $key => $name) {
				if($ecomm_to_use == $key) {
					$to_use = $key;	
				}
			}
			define('PCPP_ECOMMERCE', $to_use);
		}
	}
	add_action('init', 'pcpp_ecomm_to_use', 1);
	
	
	////////////////////////////////////////////////////////
	
	// SUBSCRIPTION MANAGEMENT CLASS
	include_once(PCPP_DIR .'/classes/subscription_manag.php');
	
	// PRIVATECONTENT ADMIN INTEGRATIONS
	include_once(PCPP_DIR . '/admin_integrations.php');
	
	// ADMIN AJAX
	include_once(PCPP_DIR . '/admin_ajax.php');
	
	// FRONT AJAX
	include_once(PCPP_DIR . '/front_ajax.php');
	
	// PRIVATECONTENT FRONTEND INTEGRATIONS
	include_once(PCPP_DIR . '/front_integrations.php');
	
	// WOOCOMMERCE INTEGRATIONS
	include_once(PCPP_DIR . '/woocom_integrations.php');
	
	// TINYMCE WIZARD INTEGRATIONS
	include_once(PCPP_DIR . '/tinymce_integration.php');
	
	// SHORTCODES
	include_once(PCPP_DIR . '/shortcodes.php');
	
	// SETTINGS
	include_once(PCPP_DIR . '/settings.php');

	// CUSTOM STYLES
	include_once(PCPP_DIR . '/custom_style.php');
	
	
	////////////
	// AUTO UPDATE DELIVER
	if(!isset($GLOBALS['is_pc_bundle'])) {
		include_once(PCPP_DIR . '/classes/lc_plugin_auto_updater.php');
		function pcpp_auto_updates() {
			$upd = new lc_wp_autoupdate(__FILE__, 'http://updates.lcweb.it', 'lc_updates');
		}
		add_action('admin_init', 'pcpp_auto_updates', 1);
	}
	////////////
}




// REQUIRE LATEST PC
function pcpp_requirements_check() {
	if(!defined('PC_VERS') || PC_VERS < 7.023) {
		
		deactivate_plugins( plugin_basename( __FILE__ ) );
		wp_die('Premium Plans add-on '. __('requires at least', 'pcpp_ml') .' PrivateContent v7.023 installed');	
	}
}
register_activation_hook(__FILE__, 'pcpp_requirements_check');



/*
//// meta keys

// pcpp_plan 			=> plan linked to user
// pcpp_subscr_end 		=> timestamp with ending subscription period or "unlimited" (for changes, check bit.ly/20qlAvU)
// pcpp_subscr_status	=> string reporting the subscription status (trial/unpaid/no_act_order/expired/active)
// pcpp_trial_ending	=> contains trial ending date or nothing if there was no trial period on registration
// pcpp_active_order 	=> last order associated to user - useful ti bind changes from order
// pcpp_orders 			=> array containing user orders 
// pcpp_last_check		=> timestamp reporting last date when logged user has been checked 

*/
