<?php
// WOOCOMMERCE INTEGRATION - ADMIN FIELDS - CHECKOUT REDIRECTS 


/*************************************
********** ADMIN FIELDS **************
*************************************/

// register in WooComm engine
function pcpp_woocomm_register_product_type() {
	class WC_Product_pvtcontent_plan extends WC_Product {
		public function __construct( $product ) {
			$this->product_type = 'pvtcontent_plan';
			parent::__construct( $product );
		}
	}
}
add_action('wp_loaded', 'pcpp_woocomm_register_product_type');


// add privatecontent plan product type in dropdown
function pcpp_wc_add_item_type($types){
  $types['pvtcontent_plan'] = __('PrivateContent Plan', 'pcpp_ml');
  return $types;
}
add_filter('product_type_selector' , 'pcpp_wc_add_item_type');



// add codes into GENERAL options
function pcpp_general_opts_code() {
	if(PCPP_ECOMMERCE != 'woocomm') {return false;}
	
	include_once(PCPP_DIR .'/functions.php');
	global $post;

	$plan_duration 	= (int)get_post_meta($post->ID, 'pcpp_plan_duration', true);
	$plan_type 		= get_post_meta($post->ID, 'pcpp_plan_dur_type', true);
	
	$not_in_forms	= get_post_meta($post->ID, 'pcpp_not_in_forms', true);
	$not_in_renewal	= get_post_meta($post->ID, 'pcpp_not_in_renew', true);
	$no_renewal		= get_post_meta($post->ID, 'pcpp_no_renewal', true);
	?>
    
    <div class="options_group pcpp_wc_fields show_if_pvtcontent_plan">
        <p class="form-field dimensions_field">
            <label><?php _e('Subscription period', 'pcpp_ml') ?></label>
            <span class="wrap">
                <input class="input-text" size="6" type="number" name="pcpp_plan_duration" value="<?php echo $plan_duration ?>" autocomplete="off" />
                
                <select name="pcpp_plan_dur_type" autocomplete="off">
                <?php
				foreach(pcpp_periods() as $type => $name) {
					$sel = ($type == $plan_type) ? 'selected="selected"' : ''; 
					echo '<option value="'.$type.'" '.$sel.'>'. $name .'</option>';	
				}
				?>
                </select>              
            </span>
            <?php echo wc_help_tip( __('Insert a value or use zero to guaratee unlimited membership', 'pcpp_ml')); ?>
        </p>
       
        <p class="form-field">
            <label><?php _e('Hide in frontend forms?', 'pcpp_ml') ?></label>
            <input class="checkbox" type="checkbox" value="1" <?php checked($not_in_forms, 1) ?> name="pcpp_not_in_forms" autocomplete="off" />
            <span class="description"><?php _e('Check to disable this product in registation forms', 'pcpp_ml') ?></span>
        </p>
        <p class="form-field">
            <label><?php _e('Hide in renewal form?', 'pcpp_ml') ?></label>
            <input class="checkbox" type="checkbox" value="1" <?php checked($not_in_renewal, 1) ?> name="pcpp_not_in_renew" autocomplete="off" />
            <span class="description"><?php _e('Check to disable this product in renewal form', 'pcpp_ml') ?></span>
        </p>
        <p class="form-field">
            <label><?php _e('Avoid renewal?', 'pcpp_ml') ?></label>
            <input class="checkbox" type="checkbox" value="1" <?php checked($no_renewal, 1) ?> name="pcpp_no_renewal" autocomplete="off" />
            <span class="description"><?php _e('If checked, customers will end their subscription at the end of the plan', 'pcpp_ml') ?></span>
        </p>
    </div>
    <?php // security nonce ?>
    <input type="hidden" name="pcpp_nonce" value="<?php echo wp_create_nonce('lcwp_nonce') ?>" />
    <?php	
}
add_action('woocommerce_product_options_general_product_data', 'pcpp_general_opts_code');




// manage everything on javascript to be faster
function pcpp_wc_admin_item_tweak() {
	if(PCPP_ECOMMERCE != 'woocomm' || get_post_type() !== 'product') {return false;}
	global $post;
	?>
	
	<script type='text/javascript'>
	jQuery(document).ready( function() {

		// handle type switch 
		var pcpp_wca_switch = function() {
			if(jQuery('#product-type').val() == 'pvtcontent_plan') {
				jQuery('.product_data_tabs.wc-tabs li').not('.general_options').hide();
				jQuery('#pcpp_wc_fields_wrap, .form-field._sale_price_field').hide();
				jQuery('.options_group.pricing').show();
				
				jQuery('#_virtual, #_sold_individually').attr('checked', 'checked');
				jQuery('#_manage_stock').removeAttr('checked');
				
				jQuery('#_stock_status option').removeAttr('selected');
				jQuery('#_stock_status option[value=instock]').attr('selected', 'selected');
			}
			else {
				jQuery('.product_data_tabs.wc-tabs li').removeAttr('style');
				jQuery('#pcpp_wc_fields_wrap').hide();
				jQuery('.form-field._sale_price_field').show();
			}
		}
		
		/// initial switch
		if(jQuery('#product-type').val() == 'pvtcontent_plan') {
			pcpp_wca_switch();
		}
		
		jQuery(document.body).delegate('#product-type', 'change', function() {
			pcpp_wca_switch();	
		});
	});
	</script>
	<?php
}
add_action('admin_footer', 'pcpp_wc_admin_item_tweak');



// Save custom fields
function pcpp_wc_meta_save($post_id) {
	if(PCPP_ECOMMERCE != 'woocomm' || isset($_POST['pcpp_nonce'])) {
		// authentication checks
		if (!wp_verify_nonce($_POST['pcpp_nonce'], 'lcwp_nonce') || $_POST['post_type'] != 'product') return $post_id;
		
		include_once(PC_DIR .'/classes/simple_form_validator.php');
				
		$validator = new simple_fv;
		$indexes = array();
		
		$indexes[] = array('index'=>'pcpp_plan_duration', 'label'=>'Subscription period');
		$indexes[] = array('index'=>'pcpp_plan_dur_type', 'label'=>'Subscription period  type');
		
		$indexes[] = array('index'=>'pcpp_not_in_forms', 'label'=>'not in frontend forms');
		$indexes[] = array('index'=>'pcpp_not_in_renew', 'label'=>'not in renewal form');
		$indexes[] = array('index'=>'pcpp_no_renewal', 'label'=>'no renewal');

		$validator->formHandle($indexes);
		
		$fdata = $validator->form_val;
		$error = $validator->getErrors();

		// clean data
		foreach($fdata as $key=>$val) {
			if(!is_array($val)) {
				$fdata[$key] = stripslashes($val);
			}
			else {
				$fdata[$key] = array();
				foreach($val as $arr_val) {$fdata[$key][] = stripslashes($arr_val);}
			}
		}

		// save data
		foreach($fdata as $key=>$val) {
			update_post_meta($post_id, $key, $fdata[$key]); 
		}
	}

    return $post_id;
}
add_action('save_post', 'pcpp_wc_meta_save');



// add text and link to PvtContent user if is a plan order
// manage everything on javascript to be faster
function pcpp_wc_admin_order_flags() {
	if(PCPP_ECOMMERCE != 'woocomm' || get_post_type() !== 'shop_order') {return false;}
	if(!isset($_GET['action']) || $_GET['action'] != 'edit') {return false;}
	global $post, $pc_users, $pcpp_subscr;

	// know if is a pvtcontent order
	$user_id = (int)get_post_meta((int)$_GET['post'], 'pvtcontent_user_id', true);
	if(empty($user_id)) {return false;}
	
	?>
	<script type='text/javascript'>
	jQuery(document).ready( function() {
		jQuery('#order_data > h2').after('<p class="order_number pcpp_is_pcpp_order_flag"><strong><?php echo addslashes( __('PrivateContent subscription order', 'pcpp_ml')) ?></strong></p>');
		
		jQuery('#s2id_customer_user').css('visibiilty', 'hidden').css('opacity', 0);

		jQuery('label[for=customer_user]').append("<a href='<?php echo admin_url('admin.php?page=pc_add_user&user='. $user_id ) ?>' target='_blank' class='pcpp_is_pcpp_order_user'><?php echo addslashes($pc_users->get_user_field($user_id, 'username')); ?></span>");
	});
	</script>
    <?php
}
add_action('admin_footer', 'pcpp_wc_admin_order_flags');



// PrivateContent pland can't actually be on discounted sale!
function pcpp_wc_no_sale_price($on_sale, $product_obj) {
	if($product_obj->get_type() == 'pvtcontent_plan') {
		return false;	
	}
	
	return $on_sale;
}
add_filter('woocommerce_product_is_on_sale', 'pcpp_wc_no_sale_price', 999, 2);





/******************************************
**** WC v3 - ALSO UNLOGGED CAN CHECKOUT ***
*******************************************/

// override WC filter
function pcpp_wc_customer_has_capability($allcaps, $caps, $args) {
	global $pcpp_subscr;
	
	if(isset( $caps[0]) && version_compare(PHP_VERSION, '3.0.0', '>=')) {
		switch ( $caps[0] ) {
			case 'pay_for_order' :
				$user_id  = $args[1];
				$order_id = isset( $args[2] ) ? $args[2] : null;
				
				// only if is a pcpp order
				if($pcpp_subscr->is_pvtcontent_order($order_id)) {
					$allcaps['pay_for_order'] = true;
				}
			break;
		}
	}
	return $allcaps;
}
add_filter('user_has_cap', 'pcpp_wc_customer_has_capability', 999, 3);




/*************************************
********* CHECKOUT REDIRECTS *********
*************************************/


// manage endpoints to customize landing pages
function pcpp_wc_cust_land_pages() {
	if(!$GLOBALS['pcpp_enabled'] || PCPP_ECOMMERCE != 'woocomm') {return false;}
	include_once(PC_DIR .'/functions.php');
	global $pcpp_subscr;

	// successful checkout
	if(is_order_received_page() && isset($_REQUEST['key'])) {
		$order_id = wc_get_order_id_by_order_key($_REQUEST['key']);
		
		if($pcpp_subscr->is_pvtcontent_order( $order_id)) {
			
			// change status to complete if it's status is processing
			$order = $pcpp_subscr->get_order($order_id);
			if($order->get_status() == 'processing') {
				$order->update_status('completed', __('Subscrption paid', 'pcpp_ml').' -', true);
			}
			
			
			// eventually perform custom redirect
			$redir = get_option('pcpp_order_ok_page', false);
			if(!empty($redir)) {
				$redir = pc_wpml_translated_pag_id($redir);
				header('Location: '. add_query_arg('pcpp_action', 'order_ok', get_permalink((int)$redir)) );	
			} 
			else {
				add_action('wp_head', 'pcpp_wc_hide_order_again_btn', 999);	
			}
		}
	}
	
	// cancelled order
	elseif(isset($_REQUEST['cancel_order']) && isset($_REQUEST['order']) && isset($_REQUEST['order_id'])) {
		$order_id = (int)$_REQUEST['order_id'];
		
		if( $pcpp_subscr->is_pvtcontent_order($order_id)) {
			
			// set order status as cancelled
			$order = $pcpp_subscr->get_order($order_id);
			$order->update_status('cancelled', __('Aborted payment', 'pcpp_ml').' -', true);
			
			// eventually perform custom redirect
			$redir = get_option('pcpp_order_del_page', false);
			if(!empty($redir)) {
				$redir = pc_wpml_translated_pag_id($redir);
				header('Location: '. add_query_arg('pcpp_action', 'del_order', get_permalink((int)$redir)) );	
			}
		}
	}
}
add_action('template_redirect', 'pcpp_wc_cust_land_pages', 1);


// utility to prevent "order again" button in default WooCommerce order received page
function pcpp_wc_hide_order_again_btn() {
	?>
    <style type="text/css">.order-again {display: none !important;}</style>
    <?php
}



/*************************************
***** HANDLE ORDER STATUS CHANGE *****
*************************************/

function pcpp_wc_order_status_change($order_id, $old_status, $new_status) {
	include_once(PCPP_DIR .'/functions.php');
	global $pc_users, $pc_meta, $pcpp_subscr;
	
	if(!$GLOBALS['pcpp_enabled'] || PCPP_ECOMMERCE != 'woocomm') {return false;}
	if($old_status == $new_status) {return false;}

	// search if user has got this order as main one 
	$args = array(
		'to_get' => array('id', 'pcpp_orders', 'status'),
		'search' => array(
			array('key' => 'pcpp_active_order', 'operator' => '=', 'val' => $order_id)
		)
	);
	$result = $pc_users->get_users($args);
	
	if(!empty($result)) {
		$ud = $result[0];
		
		if($new_status == 'cancelled' || $new_status == 'refunded' || $new_status == 'failed') {
			$pc_meta->update_meta($ud['id'], 'pcpp_subscr_status', 'expired');
			// TODO - eventually check if is the only order and set status = no_act_order
		}
		elseif($new_status == 'completed' || $new_status == 'processing') {
			$pc_meta->update_meta($ud['id'], 'pcpp_subscr_status', 'active');	
			
			// update plan's ending - starts from now
			$pc_meta->update_meta($ud['id'], 'pcpp_subscr_end', $pcpp_subscr->order_plan_expiration($order_id) );
			
			// if enable pending user
			if(get_option('pcpp_enable_pending_after_checkout')) {
				if($ud['status'] == 3) {
					$pc_users->change_status($ud['id'], 1);	
				}
			}
		}
		else {
			$pc_meta->update_meta($ud['id'], 'pcpp_subscr_status', 'unpaid');	
		}
		
		
		// if completed - set payment date in metas
		if($new_status == 'completed') {
			add_post_meta($order_id, 'pcpp_payment_date', current_time('mysql'));	
		}
	}
}
add_action('woocommerce_order_status_changed', 'pcpp_wc_order_status_change', 10, 3); 